{% block errors %}
    {% if form.non_field_errors %}
        <div class="alert alert-block alert-danger" id="form-save-error">
            {% for message in form.non_field_errors %}
                <b>{{ message }}</b><br/>
            {% endfor %}
        </div>
    {% endif %}
{% endblock %}
{% block messages %}
    {% if messages %}
        <div class="alert alert-block alert-success" id="form-save-success">
            {% for message in messages %}
                <b>{{ message }}</b><br/>
            {% endfor %}
        </div>
    {% endif %}
{% endblock %}