from .base import get_base_view_class, get_view,get_admin_domain_patterns,get_admin_login_path
from .create import AdminCreateView
from .delete import AdminDeleteView
from .export import AdminExportView
from .form import AdminFormView
from .list import AdminListView
from .update import AdminUpdateView

