{% extends 'redmin/admin/base/form.html' %}
{% block form-actions %}
    <div class="clearfix form-actions">
        <div class="col-md-offset-3 col-md-9">
            {% if object.instance_permission.savable %}
                <button class="btn btn-info" type="button" onclick="ajaxSubmit(this.form)">
                    <i class="ace-icon fa fa-check bigger-110"></i> 保存
                </button>
            {% endif %}
            <button class="btn btn-primary" type="button" onClick="history.go(-1);">
                <i class="ace-icon fa fa-mail-reply bigger-110"></i> 返回
            </button>
            <button class="btn" type="reset">
                <i class="ace-icon fa fa-undo bigger-110"></i> 重置
            </button>
            {% if model.class_permission.cloneable %}
                <a href="#!name=/{{ model_name }}/{{ object.id }}?clone" class="btn btn-success">
                    <i class="ace-icon fa fa-files-o bigger-110"></i> 复制
                </a>
            {% endif %}
        </div>
    </div>
{% endblock %}
