{% load attr %}
<div class="nav-search" id="nav-search">
        <span class="input-icon">
            <input type="text"
                   placeholder="搜索 ..."
                   class="nav-search-input" id="nav-search-inputxx"
                   autocomplete="off"
                   value="{{ request.GET|attr:'___fuzzy_search_key__' }}"
                   onchange="doSearch(this)"/>
            <i class="ace-icon fa fa-search nav-search-icon"></i>
        </span>
</div>

