<div style="display: none">
    <div id="loading-message">
        <div class="col-xs-12">
            <br/>
            <h3 class="header smaller lighter grey">
                <i class="ace-icon fa fa-spinner fa-spin orange bigger-125"></i>
                拼命加载中
                <small>.............</small>
            </h3>
        </div>
    </div>

</div>


<div style="display:none">
    -------------------------
    <div id="element-hidden">
        <input id="elementName" type="hidden" name="elementName" value="elementValue"/>
    </div>
    -------------------------
    <div id="element-text">
        <div class="form-group" id="elementName-form-group">
            <label class="col-sm-3 control-label no-padding-right">displayName</label>
            <div class="col-sm-9">
                <input type="text" class="col-xs-12 col-sm-10" name="elementName" id="elementName" value="elementValue"/>
                <div class="help-block col-xs-12 col-sm-reset inline" id="elementName-error"></div>
            </div>
        </div>
    </div>
    -------------------------
    <div id="element-password">
        <div class="form-group" id="elementName-form-group">
            <label class="col-sm-3 control-label no-padding-right">displayName</label>
            <div class="col-sm-9">
                <input type="password" class="col-xs-12 col-sm-10" name="elementName" id="elementName" value="elementValue"/>
                <div class="help-block col-xs-12 col-sm-reset inline" id="elementName-error"></div>
            </div>
        </div>
    </div>
    ------------------------
    <div id="element-select">
        <div class="form-group" id="elementName-form-group">
            <label class="col-sm-3 control-label no-padding-right">displayName</label>
            <div class="col-sm-9">
                <select class="col-xs-10 col-sm-10 chosen-select " name="elementName" id="elementName">
                    optionsReplaceMe
                </select>
                <div class="help-block col-xs-12 col-sm-reset inline" id="elementName-error"></div>
            </div>
        </div>
    </div>
    ------------------------
    <div id="element-form-actions">
        <div class="clearfix form-actions">
            <div class="col-md-offset-3 col-md-9">
                <button class="btn btn-info" type="button" onclick="doSave('form1')">
                    <i class="ace-icon fa fa-check bigger-110"></i>保存
                </button>&nbsp; &nbsp; &nbsp;
                <button class="btn" type="button" onclick="doFormCancel()">
                    <i class="ace-icon fa fa-undo bigger-110"></i>返回
                </button>
            </div>
        </div>
    </div>
    -------------------------
    <div id="index-actions">
        <div class="btn-group">
            <button class="btn btn-xs btn-danger" onclick="doDelete(elementValue)">
                <i class="ace-icon fa fa-trash-o bigger-120"></i>
            </button>
        </div>
    </div>
    ------------------------
    <div id="create-div">
        <div class="btn-group" role="group" aria-label="...">
            <button type="button" class="btn btn-info" onclick="doCreate()">添加</button>
        </div>
    </div>
    -----------------------
</div>
